@@ -5,6 +5,7 @@ use Gtk2::Ex::Graph::GD;
 use GD::Graph::Data;
 use Gtk2 -init;
 use Glib qw /TRUE FALSE/;
+use Data::Dumper;
 
 my $graph = Gtk2::Ex::Graph::GD->new(500, 300, 'bars');
 
@@ -16,8 +17,8 @@ $graph->set (
 	bar_spacing     => 1,
 	shadowclr       => 'dred',
 	transparent     => 0,
-	#cumulate		=> TRUE,
-	type => ['bars', 'bars', 'bars'],
+	# cumulate		=> TRUE,
+	type => ['lisen', 'bars', 'bars'],
 );
 
 my @legend_keys = ('Field Mice Population', 'Fish Population', 'Lobster Growth in millions');
@@ -30,6 +31,18 @@ my $data = GD::Graph::Data->new([
     [11.4,  14, 22, 16, 1.3, 15, 1, 13,  14],
 ]) or die GD::Graph::Data->error;
 
+$graph->signal_connect ('mouse-over' =>
+	sub {
+		#print Dumper @_;
+	}
+);
+
+$graph->signal_connect ('clicked' =>
+	sub {
+		print Dumper @_;
+	}
+);
+
 # This actually returns an eventbox instead of an image. 
 # But you don't <really> care either way, do you ?
 my $image = $graph->get_image($data);
